==> appmesh-1.93.0-sources.jar: software/amazon/awscdk/services/appmesh/HttpRetryPolicy.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * (experimental) HTTP retry policy.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:05.087Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.HttpRetryPolicy")
@software.amazon.jsii.Jsii.Proxy(HttpRetryPolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface HttpRetryPolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The maximum number of retry attempts.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.Number getRetryAttempts();

    /**
     * (experimental) The timeout for each retry attempt.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Duration getRetryTimeout();

    /**
     * (experimental) Specify HTTP events on which to retry.
     * <p>
     * You must specify at least one value
     * for at least one types of retry events.
     * <p>
     * Default: - no retries for http events
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> getHttpRetryEvents() {
        return null;
    }

    /**
     * (experimental) TCP events on which to retry.
     * <p>
     * The event occurs before any processing of a
     * request has started and is encountered when the upstream is temporarily or
     * permanently unavailable. You must specify at least one value for at least
     * one types of retry events.
     * <p>
     * Default: - no retries for tcp events
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> getTcpRetryEvents() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link HttpRetryPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HttpRetryPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<HttpRetryPolicy> {
        private java.lang.Number retryAttempts;
        private software.amazon.awscdk.core.Duration retryTimeout;
        private java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> httpRetryEvents;
        private java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> tcpRetryEvents;

        /**
         * Sets the value of {@link HttpRetryPolicy#getRetryAttempts}
         * @param retryAttempts The maximum number of retry attempts. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder retryAttempts(java.lang.Number retryAttempts) {
            this.retryAttempts = retryAttempts;
            return this;
        }

        /**
         * Sets the value of {@link HttpRetryPolicy#getRetryTimeout}
         * @param retryTimeout The timeout for each retry attempt. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder retryTimeout(software.amazon.awscdk.core.Duration retryTimeout) {
            this.retryTimeout = retryTimeout;
            return this;
        }

        /**
         * Sets the value of {@link HttpRetryPolicy#getHttpRetryEvents}
         * @param httpRetryEvents Specify HTTP events on which to retry.
         *                        You must specify at least one value
         *                        for at least one types of retry events.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder httpRetryEvents(java.util.List<? extends software.amazon.awscdk.services.appmesh.HttpRetryEvent> httpRetryEvents) {
            this.httpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent>)httpRetryEvents;
            return this;
        }

        /**
         * Sets the value of {@link HttpRetryPolicy#getTcpRetryEvents}
         * @param tcpRetryEvents TCP events on which to retry.
         *                       The event occurs before any processing of a
         *                       request has started and is encountered when the upstream is temporarily or
         *                       permanently unavailable. You must specify at least one value for at least
         *                       one types of retry events.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder tcpRetryEvents(java.util.List<? extends software.amazon.awscdk.services.appmesh.TcpRetryEvent> tcpRetryEvents) {
            this.tcpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent>)tcpRetryEvents;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HttpRetryPolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public HttpRetryPolicy build() {
            return new Jsii$Proxy(retryAttempts, retryTimeout, httpRetryEvents, tcpRetryEvents);
        }
    }

    /**
     * An implementation for {@link HttpRetryPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HttpRetryPolicy {
        private final java.lang.Number retryAttempts;
        private final software.amazon.awscdk.core.Duration retryTimeout;
        private final java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> httpRetryEvents;
        private final java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> tcpRetryEvents;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.retryAttempts = software.amazon.jsii.Kernel.get(this, "retryAttempts", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.retryTimeout = software.amazon.jsii.Kernel.get(this, "retryTimeout", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
            this.httpRetryEvents = software.amazon.jsii.Kernel.get(this, "httpRetryEvents", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.HttpRetryEvent.class)));
            this.tcpRetryEvents = software.amazon.jsii.Kernel.get(this, "tcpRetryEvents", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.TcpRetryEvent.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.Number retryAttempts, final software.amazon.awscdk.core.Duration retryTimeout, final java.util.List<? extends software.amazon.awscdk.services.appmesh.HttpRetryEvent> httpRetryEvents, final java.util.List<? extends software.amazon.awscdk.services.appmesh.TcpRetryEvent> tcpRetryEvents) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.retryAttempts = java.util.Objects.requireNonNull(retryAttempts, "retryAttempts is required");
            this.retryTimeout = java.util.Objects.requireNonNull(retryTimeout, "retryTimeout is required");
            this.httpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent>)httpRetryEvents;
            this.tcpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent>)tcpRetryEvents;
        }

        @Override
        public final java.lang.Number getRetryAttempts() {
            return this.retryAttempts;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getRetryTimeout() {
            return this.retryTimeout;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> getHttpRetryEvents() {
            return this.httpRetryEvents;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> getTcpRetryEvents() {
            return this.tcpRetryEvents;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("retryAttempts", om.valueToTree(this.getRetryAttempts()));
            data.set("retryTimeout", om.valueToTree(this.getRetryTimeout()));
            if (this.getHttpRetryEvents() != null) {
                data.set("httpRetryEvents", om.valueToTree(this.getHttpRetryEvents()));
            }
            if (this.getTcpRetryEvents() != null) {
                data.set("tcpRetryEvents", om.valueToTree(this.getTcpRetryEvents()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.HttpRetryPolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HttpRetryPolicy.Jsii$Proxy that = (HttpRetryPolicy.Jsii$Proxy) o;

            if (!retryAttempts.equals(that.retryAttempts)) return false;
            if (!retryTimeout.equals(that.retryTimeout)) return false;
            if (this.httpRetryEvents != null ? !this.httpRetryEvents.equals(that.httpRetryEvents) : that.httpRetryEvents != null) return false;
            return this.tcpRetryEvents != null ? this.tcpRetryEvents.equals(that.tcpRetryEvents) : that.tcpRetryEvents == null;
        }

        @Override
        public final int hashCode() {
            int result = this.retryAttempts.hashCode();
            result = 31 * result + (this.retryTimeout.hashCode());
            result = 31 * result + (this.httpRetryEvents != null ? this.httpRetryEvents.hashCode() : 0);
            result = 31 * result + (this.tcpRetryEvents != null ? this.tcpRetryEvents.hashCode() : 0);
            return result;
        }
    }
}

==> appmesh-1.182.0-sources.jar: software/amazon/awscdk/services/appmesh/HttpRetryPolicy.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * HTTP retry policy.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * VirtualRouter router;
 * VirtualNode node;
 * router.addRoute("route-http2-retry", RouteBaseProps.builder()
 *         .routeSpec(RouteSpec.http2(HttpRouteSpecOptions.builder()
 *                 .weightedTargets(List.of(WeightedTarget.builder().virtualNode(node).build()))
 *                 .retryPolicy(HttpRetryPolicy.builder()
 *                         // Retry if the connection failed
 *                         .tcpRetryEvents(List.of(TcpRetryEvent.CONNECTION_ERROR))
 *                         // Retry if HTTP responds with a gateway error (502, 503, 504)
 *                         .httpRetryEvents(List.of(HttpRetryEvent.GATEWAY_ERROR))
 *                         // Retry five times
 *                         .retryAttempts(5)
 *                         // Use a 1 second timeout per retry
 *                         .retryTimeout(Duration.seconds(1))
 *                         .build())
 *                 .build()))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.280Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.HttpRetryPolicy")
@software.amazon.jsii.Jsii.Proxy(HttpRetryPolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface HttpRetryPolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * The maximum number of retry attempts.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getRetryAttempts();

    /**
     * The timeout for each retry attempt.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Duration getRetryTimeout();

    /**
     * Specify HTTP events on which to retry.
     * <p>
     * You must specify at least one value
     * for at least one types of retry events.
     * <p>
     * Default: - no retries for http events
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> getHttpRetryEvents() {
        return null;
    }

    /**
     * TCP events on which to retry.
     * <p>
     * The event occurs before any processing of a
     * request has started and is encountered when the upstream is temporarily or
     * permanently unavailable. You must specify at least one value for at least
     * one types of retry events.
     * <p>
     * Default: - no retries for tcp events
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> getTcpRetryEvents() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link HttpRetryPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HttpRetryPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<HttpRetryPolicy> {
        java.lang.Number retryAttempts;
        software.amazon.awscdk.core.Duration retryTimeout;
        java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> httpRetryEvents;
        java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> tcpRetryEvents;

        /**
         * Sets the value of {@link HttpRetryPolicy#getRetryAttempts}
         * @param retryAttempts The maximum number of retry attempts. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder retryAttempts(java.lang.Number retryAttempts) {
            this.retryAttempts = retryAttempts;
            return this;
        }

        /**
         * Sets the value of {@link HttpRetryPolicy#getRetryTimeout}
         * @param retryTimeout The timeout for each retry attempt. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder retryTimeout(software.amazon.awscdk.core.Duration retryTimeout) {
            this.retryTimeout = retryTimeout;
            return this;
        }

        /**
         * Sets the value of {@link HttpRetryPolicy#getHttpRetryEvents}
         * @param httpRetryEvents Specify HTTP events on which to retry.
         *                        You must specify at least one value
         *                        for at least one types of retry events.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder httpRetryEvents(java.util.List<? extends software.amazon.awscdk.services.appmesh.HttpRetryEvent> httpRetryEvents) {
            this.httpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent>)httpRetryEvents;
            return this;
        }

        /**
         * Sets the value of {@link HttpRetryPolicy#getTcpRetryEvents}
         * @param tcpRetryEvents TCP events on which to retry.
         *                       The event occurs before any processing of a
         *                       request has started and is encountered when the upstream is temporarily or
         *                       permanently unavailable. You must specify at least one value for at least
         *                       one types of retry events.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tcpRetryEvents(java.util.List<? extends software.amazon.awscdk.services.appmesh.TcpRetryEvent> tcpRetryEvents) {
            this.tcpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent>)tcpRetryEvents;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HttpRetryPolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public HttpRetryPolicy build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link HttpRetryPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HttpRetryPolicy {
        private final java.lang.Number retryAttempts;
        private final software.amazon.awscdk.core.Duration retryTimeout;
        private final java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> httpRetryEvents;
        private final java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> tcpRetryEvents;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.retryAttempts = software.amazon.jsii.Kernel.get(this, "retryAttempts", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.retryTimeout = software.amazon.jsii.Kernel.get(this, "retryTimeout", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
            this.httpRetryEvents = software.amazon.jsii.Kernel.get(this, "httpRetryEvents", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.HttpRetryEvent.class)));
            this.tcpRetryEvents = software.amazon.jsii.Kernel.get(this, "tcpRetryEvents", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.TcpRetryEvent.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.retryAttempts = java.util.Objects.requireNonNull(builder.retryAttempts, "retryAttempts is required");
            this.retryTimeout = java.util.Objects.requireNonNull(builder.retryTimeout, "retryTimeout is required");
            this.httpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent>)builder.httpRetryEvents;
            this.tcpRetryEvents = (java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent>)builder.tcpRetryEvents;
        }

        @Override
        public final java.lang.Number getRetryAttempts() {
            return this.retryAttempts;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getRetryTimeout() {
            return this.retryTimeout;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.HttpRetryEvent> getHttpRetryEvents() {
            return this.httpRetryEvents;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.TcpRetryEvent> getTcpRetryEvents() {
            return this.tcpRetryEvents;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("retryAttempts", om.valueToTree(this.getRetryAttempts()));
            data.set("retryTimeout", om.valueToTree(this.getRetryTimeout()));
            if (this.getHttpRetryEvents() != null) {
                data.set("httpRetryEvents", om.valueToTree(this.getHttpRetryEvents()));
            }
            if (this.getTcpRetryEvents() != null) {
                data.set("tcpRetryEvents", om.valueToTree(this.getTcpRetryEvents()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.HttpRetryPolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HttpRetryPolicy.Jsii$Proxy that = (HttpRetryPolicy.Jsii$Proxy) o;

            if (!retryAttempts.equals(that.retryAttempts)) return false;
            if (!retryTimeout.equals(that.retryTimeout)) return false;
            if (this.httpRetryEvents != null ? !this.httpRetryEvents.equals(that.httpRetryEvents) : that.httpRetryEvents != null) return false;
            return this.tcpRetryEvents != null ? this.tcpRetryEvents.equals(that.tcpRetryEvents) : that.tcpRetryEvents == null;
        }

        @Override
        public final int hashCode() {
            int result = this.retryAttempts.hashCode();
            result = 31 * result + (this.retryTimeout.hashCode());
            result = 31 * result + (this.httpRetryEvents != null ? this.httpRetryEvents.hashCode() : 0);
            result = 31 * result + (this.tcpRetryEvents != null ? this.tcpRetryEvents.hashCode() : 0);
            return result;
        }
    }
}
